@@ -66,6 +66,5 @@ from .iqoptions.iq import iq_login, iq_buy_binary, iq_sell_binary, \
 
 # candlestick pattern
 
-from .technicalslocal.candlestick import candlestick
-
+from .technicalslocal import candlestick
     
\ No newline at end of file
